@@ -1,18 +1,16 @@
 package workspace
 
 import (
-	"bytes"
 	"context"
 	"os"
 	"path/filepath"
 	"strings"
 	"testing"
 
-	"github.com/cockroachdb/errors"
 	"github.com/google/go-cmp/cmp"
+	"github.com/sourcegraph/sourcegraph/lib/errors"
 
 	batcheslib "github.com/sourcegraph/sourcegraph/lib/batches"
-	"github.com/sourcegraph/sourcegraph/lib/batches/git"
 
 	"github.com/sourcegraph/src-cli/internal/batches/docker"
 	"github.com/sourcegraph/src-cli/internal/batches/graphql"
@@ -434,91 +432,6 @@ func TestVolumeWorkspace_WorkDir(t *testing.T) {
 	}
 }
 
-// For the below tests that essentially delegate to runScript, we're not going
-// to test the content of the script file: we'll do that as a one off test at
-// the bottom of runScript itself, rather than depending on script content that
-// may drift over time.
-
-func TestVolumeWorkspace_Changes(t *testing.T) {
-	ctx := context.Background()
-	w := &dockerVolumeWorkspace{volume: volumeID}
-
-	t.Run("success", func(t *testing.T) {
-		for name, tc := range map[string]struct {
-			stdout string
-			want   *git.Changes
-		}{
-			"empty": {
-				stdout: "",
-				want:   &git.Changes{},
-			},
-			"valid": {
-				stdout: `
-M  go.mod
-M  internal/campaigns/volume_workspace.go
-M  internal/campaigns/volume_workspace_test.go				
-				`,
-				want: &git.Changes{Modified: []string{
-					"go.mod",
-					"internal/campaigns/volume_workspace.go",
-					"internal/campaigns/volume_workspace_test.go",
-				}},
-			},
-		} {
-			t.Run(name, func(t *testing.T) {
-				expect.Commands(
-					t,
-					expect.NewGlob(
-						expect.Behaviour{Stdout: bytes.TrimSpace([]byte(tc.stdout))},
-						"docker", "run", "--rm", "--init", "--workdir", "/work",
-						"--mount", "type=bind,source=*,target=/run.sh,ro",
-						"--user", "0:0",
-						"--mount", "type=volume,source="+volumeID+",target=/work",
-						DockerVolumeWorkspaceImage,
-						"sh", "/run.sh",
-					),
-				)
-
-				have, err := w.Changes(ctx)
-				if err != nil {
-					t.Errorf("unexpected error: %v", err)
-				}
-
-				if diff := cmp.Diff(have, tc.want); diff != "" {
-					t.Errorf("unexpected changes (-have +want):\n\n%s", diff)
-				}
-
-			})
-		}
-	})
-
-	t.Run("failure", func(t *testing.T) {
-		for name, behaviour := range map[string]expect.Behaviour{
-			"exit code":        {ExitCode: 1},
-			"malformed status": {Stdout: []byte("Z")},
-		} {
-			t.Run(name, func(t *testing.T) {
-				expect.Commands(
-					t,
-					expect.NewGlob(
-						behaviour,
-						"docker", "run", "--rm", "--init", "--workdir", "/work",
-						"--mount", "type=bind,source=*,target=/run.sh,ro",
-						"--user", "0:0",
-						"--mount", "type=volume,source="+volumeID+",target=/work",
-						DockerVolumeWorkspaceImage,
-						"sh", "/run.sh",
-					),
-				)
-
-				if _, err := w.Changes(ctx); err == nil {
-					t.Error("unexpected nil error")
-				}
-			})
-		}
-	})
-}
-
 func TestVolumeWorkspace_Diff(t *testing.T) {
 	ctx := context.Background()
 	w := &dockerVolumeWorkspace{volume: volumeID}
